### R code from vignette source '03.Rnw'

###################################################
### code chunk number 1: c0
###################################################
suppressPackageStartupMessages(require(SOAR))
options(width=75)
graphics.off()
pdf(file="Fig/03_All.pdf", onefile=TRUE)
if(length(ls() > 0)) Store(ls())
options(continue="  ",
        SweaveHooks = list(fig = function() par(las = 1,
        family = "mono")))
## Sys.setenv(R_LOCAL_CACHE=".R_Store")
Attach()


###################################################
### code chunk number 2: c1 (eval = FALSE)
###################################################
## attach(birthwt)
## race <- factor(race, labels = c("white", "black", "other"))
## table(ptl)
## ptd <- factor(ptl > 0)
## table(ftv)
## ftv <- factor(ftv)
## levels(ftv)[-(1:2)] <- "2+"
## table(ftv)  # as a check
## bwt <- data.frame(low = factor(low), age, lwt, race,
##    smoke = (smoke > 0), ptd, ht = (ht > 0), ui = (ui > 0), ftv)
## detach(); rm(race, ptd, ftv)


###################################################
### code chunk number 3: c2
###################################################
suppressPackageStartupMessages(library(SOAR))  # picky!
suppressPackageStartupMessages(library(MASS))
BirthWt <- within(birthwt, {
  race <- factor(race, labels = c("white", "black", "other"))
  ptl <- ptl > 0
  ftv <- factor(ftv)
  levels(ftv)[-(1:2)] <- "2+"
  low <- factor(low, labels = c("normal", "low"))
  smoke <- (smoke > 0)
  ht <- (ht > 0)
  ui <- (ui > 0)
  bwt <- NULL ## remove actual birth weight
})
Store(BirthWt)
head(BirthWt, 2)


###################################################
### code chunk number 4: turnoff
###################################################
options(show.signif.stars = FALSE)
stepAIC <- function(..., trace = FALSE)  ## change default
    MASS::stepAIC(..., trace = trace)
dropterm <- function(..., sorted = TRUE) ## change default
    MASS::dropterm(..., sorted = sorted)


###################################################
### code chunk number 5: c1
###################################################
BW0 <- glm(low ~ ., binomial, BirthWt)
dropterm(BW0, test = "Chisq")


###################################################
### code chunk number 6: c2
###################################################
sBW0 <- stepAIC(BW0, scope = list(lower = ~1, upper = ~.^2))
dropterm(sBW0, test = "Chisq")


###################################################
### code chunk number 7: c3
###################################################
suppressPackageStartupMessages(require(mgcv))
BW1 <- gam(low ~ smoke*ui + ht + s(lwt) + ptl + s(age) +
           poly(age, 2)*ftv, family = binomial, data = BirthWt)


###################################################
### code chunk number 8: c3a (eval = FALSE)
###################################################
## anova(BW1)


###################################################
### code chunk number 9: c3b
###################################################
txt <- capture.output(anova(BW1))
txt <- txt[nchar(txt) > 0]
cat(txt, sep="\n")
rm(txt)


###################################################
### code chunk number 10: c4
###################################################
(nam <- names(model.frame(BW1)))
layout(matrix(1:8, 2, 4, byrow = TRUE))
termplot(BW1, terms = nam[2:7], se=TRUE) ## fixed
plot(BW1)                                ## smooth


###################################################
### code chunk number 11: c5
###################################################
pdf(file = "Fig/03a.pdf", height = 5, width = 9)
par(las=1)
(nam <- names(model.frame(BW1)))
layout(matrix(1:8, 2, 4, byrow = TRUE))
termplot(BW1, terms = nam[2:7], se=TRUE) ## fixed
plot(BW1)                                ## smooth
dev.off()


###################################################
### code chunk number 12: mfv
###################################################
mostFreq <- function(x, ...) UseMethod("mostFreq")
mostFreq.numeric <- stats::median.default  ## check argument names
mostFreq.logical <- function(x, ...) {
  tx <- as.vector(table(x))
  tx[2] > tx[1]
}
mostFreq.character <- function(x, ...) {
  tx <- table(x)
  names(tx)[which.max(tx)]
}
mostFreq.factor <- function(x, ...)
    mostFreq.character(as.character(x))
Store(list = ls(pattern = "^mostFreq"))


###################################################
### code chunk number 13: c6
###################################################
all.vars(formula(BW1))
pBirthWt <- with(BirthWt,
    expand.grid(smoke = mostFreq(smoke), ui = mostFreq(ui),
                ht = mostFreq(ht), lwt = mostFreq(lwt),
                ptl = mostFreq(ptl), age = min(age):max(age),
                ftv = levels(ftv)))
pBirthWt$pBW1 <- predict(BW1, pBirthWt, type = "response")
library(lattice)
(ageFtv <- xyplot(pBW1 ~ age|ftv, pBirthWt, layout = c(3,1),
                  type = "l", ylab = "Pr(low birth wt)",
                  ylim = 0:1, aspect = 1))


###################################################
### code chunk number 14: c6a
###################################################
pBirthWt <- within(pBirthWt, {
    rngs <- do.call(cbind, with(BirthWt, tapply(age, ftv, range)))
    pBW1a <- pBW1
    is.na(pBW1a[age < rngs[1, ftv] | age > rngs[2, ftv]]) <- TRUE
    rm(rngs)
})
(ageFtvA <- xyplot(pBW1a ~ age|ftv, pBirthWt, layout = c(3,1),
                   type = "l", ylab = "Pr(low birth wt)",
                   ylim = 0:1, aspect = 1))


###################################################
### code chunk number 15: c7
###################################################
pdf(file = "Fig/03b.pdf", height = 15/2, width = 15/2)
print(ageFtv, position = c(0,0.5,1,1), more = TRUE)
print(ageFtvA, position = c(0,0,1,0.5), more = FALSE)
dev.off()


###################################################
### code chunk number 16: d1
###################################################
AttachData()
pal <- white_lemon_orange_red
Attach()

NPF0(col = grey(0.5))
ncols <- with(teff, 1 + ceiling(log(1 + TigerE)))
cols <- pal(max(ncols))[ncols]

points(Latitude ~ Longitude, teff, pch = 15, cex = 0.5, col=cols)
lines(ShortCC, col="navy", lwd=2)
lines(Oz)


###################################################
### code chunk number 17: d2
###################################################
Annual


###################################################
### code chunk number 18: d3
###################################################
library(splines)
temp <- glm(Psem/Total ~ ns(Coast, 10) + ns(Sea, 5) + ns(Depth, 5) +
            ns(Mud, 4) + Annual(DayOfYear, 4)*Sea, family = quasibinomial,
            data = Tigers, trace = TRUE)  ## unweighted
Tigers$eta <- predict(temp)


###################################################
### code chunk number 19: d3a
###################################################
TModelGLM <- update(temp, etastart = eta, weights = Total)
rm(temp)
Tigers$eta <- predict(TModelGLM)
TModelGLM$call$trace <- NULL  ## for future updating
Store(TModelGLM)
(nam <- names(model.frame(TModelGLM)))  ## for term plotting
nam <- nam[2:7]                         ## terms to plot


###################################################
### code chunk number 20: d4 (eval = FALSE)
###################################################
## layout(matrix(1:6, 2, 3, byrow=TRUE))   ## 2 x 3 array of plots
## termplot(TModelGLM, terms = nam, se = TRUE, rug=TRUE)


###################################################
### code chunk number 21: d5
###################################################
pdf(file="Fig/03tm1.pdf", height = 6, width = 9)
par(las = 1)
layout(matrix(1:6, 2, 3, byrow=TRUE))   ## 2 x 3 array of plots
termplot(TModelGLM, terms = nam, se = TRUE, rug=TRUE)
dev.off()


###################################################
### code chunk number 22: d6
###################################################
TM2 <- update(TModelGLM, . ~ . + ns(ElapsedDays, 7))
anova(TModelGLM, TM2, test = "F")


###################################################
### code chunk number 23: d7
###################################################
termplot(TM2, terms = "ns(ElapsedDays, 7)", se=TRUE, rug = TRUE)


###################################################
### code chunk number 24: d8 (eval = FALSE)
###################################################
## require(mgcv)
## Attach()
## TModelGAM <- gam(Psem/Total ~ s(Longitude, Latitude) +
##                  te(DayOfYear, Sea, k = c(5, 5), bs = c("cc", "cs")) +
##                  te(DayOfYear, Depth, k = c(5, 5), bs = c("cc", "cs")) +
##                  te(Sea, Depth, k = c(5, 5), bs = "cs") +
##                  s(Mud, k = 5),
##                  family = quasibinomial, data = Tigers,
##                  knots = list(DayOfYear = seq(0, 365.25, length=5)),
##                  weights = Total, control = gam.control(trace = TRUE))
## TModelGAM_NS <- update(TModelGAM, . ~ . + s(ElapsedDays))  ## non-stationary


###################################################
### code chunk number 25: 03.Rnw:538-555 (eval = FALSE)
###################################################
## png(file = "Fig/03tm2_%03d.png", height = 500, width = 900)
## par(las = 1)
## layout(rbind(1:2))
## plot(TModelGAM_NS, select = 1, asp = 1)
## lines(Oz, col = grey(0.8))
## title(main = "Lon x Lat, isotropic")
## for(j in 2:6)
##     plot(TModelGAM_NS, select = j)
## vis.gam(TModelGAM_NS, view = c("Longitude","Latitude"))
## title(main = "Lon x Lat, isotropic")
## vis.gam(TModelGAM_NS, view = c("DayOfYear","Sea"))
## title(main = "Day of year x Sea")
## vis.gam(TModelGAM_NS, view = c("DayOfYear","Depth"))
## title(main = "Day of year x Depth")
## vis.gam(TModelGAM_NS, view = c("Depth","Mud"))
## title(main = "Depth x Mud")
## dev.off()


###################################################
### code chunk number 26: e1
###################################################
Attach()
par(mar=c(0,0,0,0))
plot(cc, type = "n", ann=FALSE,axes=FALSE, asp=1, bty="n")
points(Locz, pch=20, cex = 1.5, col="red")
text(Latitude ~ Longitude, data = data4, Place, pos = c(4,4,3,2),
     col = "navy")
lines(Oz, col=grey(0.5))


###################################################
### code chunk number 27: e2
###################################################
Attach()
require(lattice)
print(xyplot(Fsemi ~ DayOfYear|Place, Data4, type = "l",
  ylab=expression(italic(P.)~~italic(semisulcatus)~~plain(proportion)),
  xlab = "Day of the year", aspect = 0.7))


###################################################
### code chunk number 28: 03.Rnw:610-611 (eval = FALSE)
###################################################
## Attach()
## require(lattice)
## print(xyplot(Fsemi ~ DayOfYear|Place, Data4, type = "l",
##   ylab=expression(italic(P.)~~italic(semisulcatus)~~plain(proportion)),
##   xlab = "Day of the year", aspect = 0.7))


###################################################
### code chunk number 29: 03.Rnw:649-651
###################################################
toLatex(sessionInfo())
graphics.off()


